# pYPKa_Z_TDH3tp

Plan for the construction of E. coli vector pYPKa_Z_TDH3tp

# Step 1 PCR of the insert

PCR with primers pfw698 & prv698 and template TDH3_template results in a 711bp PCR product

Primers annealing on template:

          5ATAAAAAACACGCTTTTTC...AACACACATAAACAAACAAA3
                                 |||||||||||||||||||| tm 44.1 (dbd) 54.7
                                3TTGTGTGTATTTGTTTGTTTaattaat5
    5ttaaatATAAAAAACACGCTTTTTC3
           ||||||||||||||||||| tm 42.7 (dbd) 55.3
          3TATTTTTTGTGCGAAAAAG...TTGTGTGTATTTGTTTGTTT5

Suggested PCR programs for Taq polymerase and for Polymerases with DNA binding domain:

    Taq (rate 30 nt/s) 35 cycles             |711bp
    95.0°C    |95.0°C                 |      |SantaLucia 1998
    |_________|_____          72.0°C  |72.0°C|SaltC 50mM
    | 03min00s|30s  \         ________|______|
    |         |      \ 50.0°C/ 0min21s| 5min |
    |         |       \_____/         |      |
    |         |         30s           |      |4-12°C

# Step 2 Vector digestion and cloning

Clone the PCR product in pYPKa digested with ZraI resulting in pYPKa_Z_TDH3tp

# Step 3 Diagnostic PCR confirmation

Confirm the structure of the pYPKa_Z_TDH3tp using primers 577, 342 and pfw698 in a multiplex PCR reaction.

Expected PCR products sizes from 577, 342 and pfw698 (bp):

pYPKa with insert in correct orientation: 1645, 1477
pYPKa with insert in reverse orientation: 1645, 879
Empty pYPKa clone : 934